/**
 * @module articleInstanceCommentsRoute
 * @description Baasic Article Instance Comments Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Article Instance Comments Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
*/
import { BaseRoute } from '../../../common';
import { IGetRequestOptions, IOptions } from '../../../common/contracts';
import { IAppOptions } from '../../../core/contracts';
import { ArticleInstanceCommentRepliesRoute } from '../';
import { IArticle, IArticleComment } from '../contracts';
export declare class ArticleInstanceCommentsRoute extends BaseRoute {
    protected articleInstanceCommentRepliesRoute: ArticleInstanceCommentRepliesRoute;
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly createRoute: string;
    readonly updateRoute: string;
    readonly deleteRoute: string;
    readonly deleteAllRoute: string;
    readonly approveRoute: string;
    readonly unapproveRoute: string;
    readonly flagRoute: string;
    readonly unflagRoute: string;
    readonly reportRoute: string;
    readonly unreportRoute: string;
    readonly spamRoute: string;
    readonly unspamRoute: string;
    readonly replies: ArticleInstanceCommentRepliesRoute;
    constructor(articleInstanceCommentRepliesRoute: ArticleInstanceCommentRepliesRoute, appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string value used to identify article comment resources using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain article comment subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the article comment property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * - `statuses` - Comma separated list of article comment states that specify where search should be done (Allowed states: Approved, Spam, Reported, Flagged and UnApproved).
     * @method
     * @param articleId Article slug or id which uniquely identifies article whose comment resources need to be retrieved.
     * @param options Query resource options object.
     * @example articleInstanceCommentsRoute.find({ searchQuery: '<search-phrase>' });
     **/
    find(articleId: string, options?: IOptions): any;
    /**
     * Parses get route which can be expanded with additional options. Supported items are:
     * - `id` - Id which uniquely identifies article comment resource that needs to be retrieved.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param articleId Article slug or id which uniquely identifies article whose comment resource needs to be retrieved.
     * @param commentId Id which identifies article comment resource that needs to be retrieved.
     * @param options Options object that contains embed data.
     * @example articleInstanceCommentsRoute.get().expand({ id: '<comment-id>' });
     **/
    get(articleId: string, commentId?: string, options?: IGetRequestOptions): any;
    /**
     * Parses create route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object that needs to be inserted into the system.
     * @example articleInstanceCommentsRoute.create(data);
     **/
    create(data: IArticleComment): any;
    /**
     * Parses update route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comments object used to update specified article comment resource.
     * @example articleInstanceCommentsRoute.update(data);
     **/
    update(data: IArticleComment): any;
    /**
     * Parses delete route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comments object used to delete specified article comment resource.
     * @example articleInstanceCommentsRoute.delete(data);
     **/
    delete(data: IArticleComment): any;
    /**
     * Parses delete all route; this URI template doesnt support any additional options.
     * @method
     * @param data An article object used to delete specified article comment resource.
     * @example articleInstanceCommentsRoute.deleteAll(data);
     **/
    deleteAll(data: IArticle): any;
    /**
     * Parses approve route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.approve(data);
     **/
    approve(data: IArticleComment): any;
    /**
     * Parses unapprove route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.unapprove(data);
     **/
    unapprove(data: IArticleComment): any;
    /**
     * Parses flag route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.flag(data);
     **/
    flag(data: IArticleComment): any;
    /**
     * Parses unflag route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.unflag(data);
     **/
    unflag(data: IArticleComment): any;
    /**
     * Parses report route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.report(data);
     **/
    report(data: IArticleComment): any;
    /**
     * Parses unreport route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.unreport(data);
     **/
    unreport(data: IArticleComment): any;
    /**
     * Parses spam route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.spam(data);
     **/
    spam(data: IArticleComment): any;
    /**
     * Parses unspam route; this URI template doesnt support any additional options.
     * @method
     * @param data An article comment object.
     * @example articleInstanceCommentsRoute.unspam(data);
     **/
    unspam(data: IArticleComment): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
*/ 
