/**
 * @module calendarEventsRoute
 * @description BaasicCalendarEventsRoute Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use BaasicCalendarEventsRoute Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../../common';
import { IGetRequestOptions } from '../../../../common/contracts';
import { IAppOptions } from '../../../../core/contracts';
import { ICalendarEvent, IGetCalendarEventsOptions } from '../../contracts';
export declare class CalendarEventsRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly getByEmailOrFullNameRoute: string;
    readonly linkRoute: string;
    readonly updateRoute: string;
    readonly unlinkRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional GetCalendarEventOptions. Supported items are:
     * - `searchQuery` - A string referencing CalendarEvent properties using the phrase or BQL (Baasic Query Language) search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain CalendarEvent subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the CalendarEvent property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * - `ids` - CalendarEvent ids which uniquely identify CalendarEvent resources that need to be retrieved.
     * - `ownerIds` - Owner ids which uniquely identify event owners used for filtering.
     * - `statusIds` - CalendarEventStatus ids which uniquely idendify CalendarEventStatuses used for filtering.
     * - `typeIds` - CalendarEventType ids which uniquely identify CalendarEventTypes used for filtering.
     * - `from` - Fluent syntax for 'From' date. Used to limit the dataset to only use resources starting from this date
     * - `to` - Fluent syntax for 'To' date. Used to limit the dataset to only use resources ending to this date.
     * @method
     * @param calendarId Calendar identifier which uniquely identifies a calendar resource.
     * @param options Query resource GetCalendarEventsOptions object.
     * @example calendarEventsRoute.find(calendarId, {searchQuery: '<search-phrase>'});
     */
    find(calendarId: string, options?: IGetCalendarEventsOptions): any;
    /**
     * Parses get route which must be expanded with the identifier of the previously created CalendarEvent resource. This route can be expanded using additional GetRequestOptions. Supported items are:
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param calendarId Calendar id which uniquely identifies Calendar resource.
     * @param id CalendarEvent id which uniquely identifies CalendarEvent resource that needs to be retrieved.
     * @param options Query resource options object.
     * @example calendarEventsRoute.get(id);
     */
    get(calendarId: string, id: string, options?: IGetRequestOptions): any;
    /**
     * Parses getByEmailOrFullName route which must be expanded with the identifier of the previously created CalendarEvent resource
     * The route must also be expanded with the identifier of the previously created CalendarResource and the email/FullName.
     * @param calendarId Calendar identifier which uniquely identifies previously created calendar resource.
     * @param id CalendarEvent identifier which uniquely identifies previously created CalendarEvent resource.
     * @param emailOrFullName Email or full name.
     * @param options Query resource options object.
     * @example calendarEventsRoute.get(calendarId, id, email@example.com, options);
     */
    getByEmailOrFullName(calendarId: string, id: string, emailOrFullName: string, options?: IGetRequestOptions): any;
    /**
     * Parses link route. This URI template does not expose any additional options.
     * @method
     * @param data A calendarEvent resource to be linked.
     * @param calendarId A calendar identifier which uniquely identifies a calendar resource.
     * @example calendarEventsRoute.create(calendarid, eventid);
     */
    link(calendarId: string, data: ICalendarEvent): any;
    /**
     * Parses update route. This URI template does not expose any additional options.
     * @method
     * @param data A CalendarEvent object used to update specified CalendarEvent resource.
     * @param calendarId A calendar identifier which uniquely identifies a calendar resourse.
     * @example calendarEventsRoute.update(calendarid, data);
     */
    update(calendarId: string, data: ICalendarEvent): any;
    /**
     * Parses unlink route. This URI template does not expose any additional options.
     * @method
     * @param data A calendarEvent resource to be unlinked.
     * @param calendarId A calendar identifier which uniquely identifies a calendar resourse.
     * @example calendarEventsRoute.unlink(calendarid, eventid);
     */
    unlink(calendarId: string, data: ICalendarEvent): any;
    protected getToDate(options: any): any;
    protected getFromDate(options: any): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
