/**
 * @module calendarRsvpAttendeeRoute
 * @description BaasicCalendarRsvpAttendeeRoute Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use BaasicCalendarRsvpAttendeeRoute Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../../common';
import { IGetRequestOptions } from '../../../../common/contracts';
import { IAppOptions } from '../../../../core/contracts';
import { ICalendarEventAttendee, IGetCalendarRsvpAttendeeOptions } from '../../contracts';
export declare class CalendarRsvpAttendeeRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly getByEmailOrFullNameRoute: string;
    readonly linkRoute: string;
    readonly updateRoute: string;
    readonly updateStatusRoute: string;
    readonly updateStatusByEmailOrFullNameRoute: string;
    readonly unlinkRoute: string;
    readonly purgeRoute: string;
    readonly subscribeEmailRoute: string;
    readonly unsubscribeEmailRoute: string;
    readonly subscribeRoute: string;
    readonly unsubscribeRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional GetCalendarLookupOptions. Supported items are:
     * - `searchQuery` - A string referencing CalendarEventAttendee properties using the phrase or BQL (Baasic Query Language) search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain CalendarEventAttendee subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the CalendarEventAttendee property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * - `ids` - CalendarEventAttendee ids which uniquely identify CalendarEventAttendee resources that need to be retrieved.
     * - `userIds` - CalendarEventAttende userIds which identify CalendarEventAttendee resources.
     * - `emails` - CalendarEventAttendee emails which identify CalendarEventAttendee resources.
     * - `fullNames` - CalendarEventAttendee full names which identify CalendarEventAttendee resources.
     * - `invitationTypeIds` - invitationTypeIds which identify CalendarEventAttendee resources.
     * - `from` - Fluent syntax for 'From' date. Used to limit the dataset to only use resources starting from this date.
     * - `to` - Fluent syntax for 'To' date. Used to limit the dataset to only use resources ending to this date.
     * @method
     * @param options Query resource GetCalendarLookupOptions object.
     * @param calendarId Calendar identifier which uniquely identifies a calendar resource.
     * @param eventId calendarEvent identifier which uniquely identifies a CalendarEvent resource.
     * @example calendarRsvpAttendeeRoute.find(calendarid, eventid, {searchQuery: '<search-phrase>'});
     */
    find(calendarId: string, eventId: string, options?: IGetCalendarRsvpAttendeeOptions): any;
    /**
     * Parses get route which must be expanded with the id of the previously created CalendarEventAttendee resource in the system. The route can be expanded using additional GetRequestOptions. Supported items are
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param id CalendarEventAttendee id which uniquely identifies CalendarEventAttendee resource that needs to be retrieved.
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param options Query resource GetRequestOptions object.
     * @example calendarRsvpAttendeeRoute.get(calendarId, eventId, id);
     */
    get(calendarId: string, eventId: string, id: string, options?: IGetRequestOptions): any;
    /**
     * @method
     * @param calendarId Calendar Id which uniquely identifies a Calendar resource.
     * @param eventId CalendarEvent Id which uniquely identifies a calendarEvent resource
     * @param emailOrFullName Email or full name which identify a CalendarEventRsvpAttendee resource.
     * @param options Query resource options ovject.
     * @example calendarRsvpAttendeeRoute.getByEmailOrFullName(calendarId, eventId, fullname);
     */
    getByEmailOrFullName(calendarId: string, eventId: string, emailOrFullName: string, options: IGetRequestOptions): any;
    /**
     * Parses link route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies a CalendarEvent resource
     * @param data A CalendarEventAttendee object that needs to be inserted into the system.
     * @example calendarRsvpAttendeeRoute.link(calendarId, eventId, data);
     */
    link(calendarId: string, eventId: string, data: ICalendarEventAttendee): any;
    /**
     * Parses purge route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniquely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @example calendarRsvpAttendeeRoute.purge(calendarId, eventId);
     */
    purge(calendarId: string, eventId: string): any;
    /**
     * Parses update route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param data A CalendarEventAttendee object used to update specified CalendarEventAttendee resource.
     * @example calendarRsvpAttendeeRoute.update(calendarId, eventId, data);
     */
    update(calendarId: string, eventId: string, data: ICalendarEventAttendee): any;
    /**
     * Parses update Status route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param id CalendarEventAttendee id which uniquely identifies CalendarEventAttendee resource.
     * @param statusId CalendarEventAttendeeStatus id which uniquely identifies CalendarEventAttendeeStatus resource.
     * @example calendarRsvpAttendeeRoute.updateStatus(calendarId, eventId, id, statusId);
     */
    updateStatus(calendarId: string, eventId: string, id: string, statusId: string): any;
    /**
     * Parses update status email or name route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniqely identifies CalendarEvent resource.
     * @param emailOrFullName Email or FullName
     * @param statusId CalendarEventAttendeeStatus id which uniquely identifies CalendarEventAttendeeStatus resource.
     * @example calendarRsvpAttendeeRoute.update(calendarId, eventId, email, statusId);
     */
    updateStatusEmailOrFullName(calendarId: string, eventId: string, emailOrFullName: string, statusId: string): any;
    /**
     * Parses unlink route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param data A CalendarEventAttendee object used to unlink specified CalendarEventAttendee resource.
     * @example calendarRsvpAttendeeRoute.delete(calendarId, eventId, data);
     */
    unlink(calendarId: string, eventId: string, data: ICalendarEventAttendee): any;
    /**
     * Parses subscribe route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param id CalendarEventAttendee id which uniquely identifies CalendarEventAttendee resource.
     * @example calendarRsvpAttendeeRoute.subscribe(calendarId, eventId, attendeeId);
     */
    subscribe(calendarId: string, eventId: string, id: string): any;
    /**
     * Parses unsubscribe route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param id CalendarEventAttendee id which uniquely identifies CalendarEventAttendee resource.
     * @example calendarRsvpAttendeeRoute.unsubscribe(calendarId, eventId, attendeeId);
     */
    unsubscribe(calendarId: string, eventId: string, id: string): any;
    /**
     * Parses subscribeEmail route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param email CalendarEventAttendee email which identifies CalendarEventAttendee resource.
     * @example calendarRsvpAttendeeRoute.subscribe(calendarId, eventId, attendeeId);
     */
    subscribeEmail(calendarId: string, eventId: string, email: string): any;
    /**
     * Parses unsubscribeEmail route. This URI template does not expose any additional options.
     * @method
     * @param calendarId Calendar id which uniqely identifies Calendar resource.
     * @param eventId CalendarEvent id which uniquely identifies CalendarEvent resource.
     * @param email CalendarEventAttendee email which identifies CalendarEventAttendee resource.
     * @example calendarRsvpAttendeeRoute.unsubscribe(calendarId, eventId, attendeeId);
     */
    unsubscribeEmail(calendarId: string, eventId: string, email: string): any;
    protected getToDate(options: any): any;
    protected getFromDate(options: any): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
