/**
 * @module userProfileClient
 * @description  User Profile Client provides an easy way to consume  User Profile REST API end-points. In order to obtain needed routes `userProfileClient` uses `userProfileRoute`.
 */
import { IQueryModel, IGetRequestOptions, IOptions } from '../../common/contracts';
import { ApiClient, IHttpResponse } from '../../httpApi';
import { UserProfileACLClient, UserProfileRoute, UserEducationClient, UserProfileAvatarClient, UserSkillClient, UserWorkClient } from './';
import { IUserProfile } from './contracts';
export declare class UserProfileClient {
    protected userProfileACLClient: UserProfileACLClient;
    protected userProfileRoute: UserProfileRoute;
    protected apiClient: ApiClient;
    protected userEducationClient: UserEducationClient;
    protected userProfileAvatarClient: UserProfileAvatarClient;
    protected userSkillClient: UserSkillClient;
    protected userWorkClient: UserWorkClient;
    readonly acl: UserProfileACLClient;
    readonly routeDefinition: UserProfileRoute;
    readonly education: UserEducationClient;
    readonly avatar: UserProfileAvatarClient;
    readonly skill: UserSkillClient;
    readonly work: UserWorkClient;
    constructor(userProfileACLClient: UserProfileACLClient, userProfileRoute: UserProfileRoute, apiClient: ApiClient, userEducationClient: UserEducationClient, userProfileAvatarClient: UserProfileAvatarClient, userSkillClient: UserSkillClient, userWorkClient: UserWorkClient);
    /**
     * Returns a promise that is resolved once the find action has been performed. Success response returns a list of user profile resources matching the given criteria.
     * @method
     * @param options Query resource options object.
     * @returns A promise that is resolved once the find action has been performed.
     * @example userProfileClient.find({
                    pageNumber : 1,
                    pageSize : 10,
                    orderBy : '<field>',
                    orderDirection : '<asc|desc>',
                    search : '<search-phrase>'
                })
                .then(function (collection) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                     // perform error handling here
                });
     **/
    find(options?: IOptions): PromiseLike<IHttpResponse<IQueryModel<IUserProfile>>>;
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the user profile resource.
     * @method
     * @param id User profile id which uniquely identifies user profile resource that needs to be retrieved.
     * @param options Query resource options object.
     * @returns A promise that is resolved once the get action has been performed.
     * @example userProfileClient.get()
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                         // perform error handling here
                    });
     **/
    get(id: string, options?: IGetRequestOptions): PromiseLike<IHttpResponse<IUserProfile>>;
    /**
     * Returns a promise that is resolved once the create user profile action has been performed; this action creates a new user profile resource.
     * @method
     * @param data An user profile object that needs to be inserted into the system.
     * @returns A promise that is resolved once the create user profile action has been performed.
     * @example userProfileClient.create({
                    firstName : '<first-name>',
                    lastName : '<last-name>',
                    displayName: '<nick-name>'
                }.then(function (data) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                     // perform error handling here
                });
     **/
    create(data: IUserProfile): PromiseLike<IHttpResponse<IUserProfile>>;
    /**
     * Returns a promise that is resolved once the update user profile action has been performed; this action updates a user profile resource. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `userProfileRoute` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(userProfile);
     * let uri = params['model'].links('put').href;
     * ```
     * @method
     * @param data An user profile object used to update specified user profile resource.
     * @returns A promise that is resolved once the update user profile action has been performed.
     * @example // userProfile is a resource previously fetched using get action.
                       userProfile.displayName = '<nick-name>';
                       userProfileClient.update(userProfile)
                           .then(function (data) {
                               // perform success action here
                           },
                            function (response, status, headers, config) {
                                // perform error handling here
                           });
    **/
    update(data: IUserProfile): PromiseLike<IHttpResponse<void>>;
    /**
     * Returns a promise that is resolved once the remove action has been performed. This action will remove a user profile resource from the system if successfully completed. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `userProfileRoute` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(userProfile);
     * let uri = params['model'].links('delete').href;
     * ```
     * @method
     * @param data An user profile object used to delete specified user profile resource.
     * @returns A promise that is resolved once the remove action has been performed.
     * @example // userProfile is a resource previously fetched using get action.
                    userProfileClient.remove(userProfile)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                             // perform error handling here
                        });
     **/
    remove(data: IUserProfile): PromiseLike<IHttpResponse<void>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route definition.
 */ 
