/**
 * @module applicationSettingsClient
 * @description  Application Settings Client provides an easy way to consume  Application Settings REST API end-points. In order to obtain needed routes `applicationSettingsClient` uses `applicationSettingsRoute`.
 */
import { IOptions, IQueryModel } from '../../../common/contracts';
import { ApiClient, IHttpResponse } from '../../../httpApi';
import { ApplicationSettingsRoute } from './';
import { IPlatformApplication, INewPlatformApplication } from './contracts';
export declare class ApplicationSettingsClient {
    protected applicationSettingsRoute: ApplicationSettingsRoute;
    protected apiClient: ApiClient;
    /**
     * Provides direct access to `applicationSettingsRoute`.
     * @method
     * @example ApplicationSettingsClient.routeDefinition.get(options)
     **/
    readonly routeDefinition: ApplicationSettingsRoute;
    constructor(applicationSettingsRoute: ApplicationSettingsRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the find action has been performed. Success response returns a list of application resources matching the given criteria.
     * @method
     * @param options Query resource options object.
     * @example applicationClient.find({
                    pageNumber : 1,
                    pageSize : 10,
                    orderBy : '<field>',
                    orderDirection : '<asc|desc>',
                    search : '<search-phrase>'
                })
                .then(function (collection) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    find(options?: IOptions): PromiseLike<IHttpResponse<IQueryModel<IPlatformApplication>>>;
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the specified application resource.
     * @method
     * @param id A application identifier.
     * @param options Query resources options.
     * @returns A promise that is resolved once the get action has been performed.
     * @example applicationClient.get({
                    id : '<id>',
                })
                .then(function (data) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    get(id: string): PromiseLike<IHttpResponse<IPlatformApplication>>;
    /**
     * Returns a promise that is resolved once the create application action has been performed; this action creates a new application.
     * @method
     * @param data An application object that needs to be inserted into the system.
     * @returns A promise that is resolved once the create application action has been performed.
     * @example applicationClient.create({
                    email : '<email>',
                    password : '<password>',
                    name : '<name>',
                    identifier : '<identifier>',
                    additionalProperty: '<additional-property>'
                })
                .then(function (data) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    create(data: INewPlatformApplication): PromiseLike<IHttpResponse<IPlatformApplication>>;
    /**
     * Returns a promise that is resolved once the update application action has been performed; this action updates a application.
     * @param data A application object used to update specified application resource.
     * @returns A promise that is resolved once the update application action has been performed.
     * @method
     * @example  applicationClient.update(application)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    update(data: IPlatformApplication): PromiseLike<IHttpResponse<any>>;
    /**
     * Returns a promise that is resolved once the remove application action has been performed. This action will remove a application from the system if successfully completed.
     * @method
     * @param data  A application object used to delete specified application resource.
     * @returns A promise that is resolved once the remove application action has been performed.
     * @example applicationClient.remove(application)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    remove(data: IPlatformApplication): PromiseLike<IHttpResponse<any>>;
    /**
     * Returns a promise that is resolved once the update application activate action has been performed; this action activates a application.
     * @param data A application object used to activate specified application resource.
     * @returns A promise that is resolved once the activate application action has been performed.
     * @method
     * @example  applicationClient.activate(id)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    activate(id: string): PromiseLike<IHttpResponse<any>>;
    /**
     * Returns a promise that is resolved once the deactivate application action has been performed; this action deactivate a application.
     * @param data A application object used to deactivate specified application resource.
     * @returns A promise that is resolved once the deactivate application action has been performed.
     * @method
     * @example  applicationClient.deactivate(id)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    deactivate(id: string): PromiseLike<IHttpResponse<any>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route service.
 */ 
